``zope.dottedname``
===================

Resolve strings containing dotted names into the appropriate python object.

See ``src/zope/dottedname/README.txt`` for more information.

Travis: |buildstatus|_
winbot: |winbotstatus|_

.. |buildstatus| image:: https://api.travis-ci.org/zopefoundation/zope.dottedname.png?branch=master
.. _buildstatus: https://travis-ci.org/zopefoundation/zope.dottedname

.. |winbotstatus| image:: http://winbot.zope.org/buildstatusimage?builder=zope.dottedname_py_265_32&number=-1
.. _winbotstatus: http://winbot.zope.org/builders/zope.dottedname_py_265_32/builds/-1
